from django import template
register = template.Library()

@register.filter
def is_tuple(value):
    """Tell if this value is a tuple or not.

    @param value (obj): any object
    @return: True if value is a tuple
    """
    # XXX: we would like to have is_type with an argument instead, but it would
    # rely on a strange comparison - isinstance(value, arg) doesn't work here
    return type(value) == tuple

@register.filter
def buffer(value, n):
    """Split values in sub-lists of n elements.

    @param value (list): a list object
    @return: a list containing sub-lists

    For example:

    >>> buffer(range(10), 2)
    [[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]

    >>> buffer(range(10), 3)
    [[0, 1, 2], [3, 4, 5], [6, 7, 8], [9]]

    >>> buffer(range(10), 4)
    [[0, 1, 2, 3], [4, 5, 6, 7], [8, 9]]
    """
    result = []
    index = 0
    while index < len(value):
        result.append(value[index:index + n])
        index += n
    return result
